# Block Types Data

Namespace: `core/blocks`.

## Selectors

<!-- START TOKEN(Autogenerated selectors|../../../packages/blocks/src/store/selectors.js) -->

### getActiveBlockVariation

Returns the active block variation for a given block based on its attributes.
Variations are determined by their `isActive` property.
Which is either an array of block attribute keys or a function.

In case of an array of block attribute keys, the `attributes` are compared
to the variation's attributes using strict equality check.

In case of function type, the function should accept a block's attributes
and the variation's attributes and determines if a variation is active.
A function that accepts a block's attributes and the variation's attributes and determines if a variation is active.

_Parameters_

-   _state_ `Object`: Data state.
-   _blockName_ `string`: Name of block (example: “core/columns”).
-   _attributes_ `Object`: Block attributes used to determine active variation.
-   _scope_ `[WPBlockVariationScope]`: Block variation scope name.

_Returns_

-   `(WPBlockVariation|undefined)`: Active block variation.

### getBlockStyles

Returns block styles by block name.

_Parameters_

-   _state_ `Object`: Data state.
-   _name_ `string`: Block type name.

_Returns_

-   `Array?`: Block Styles.

### getBlockSupport

Returns the block support value for a feature, if defined.

_Parameters_

-   _state_ `Object`: Data state.
-   _nameOrType_ `(string|Object)`: Block name or type object
-   _feature_ `Array|string`: Feature to retrieve
-   _defaultSupports_ `*`: Default value to return if not explicitly defined

_Returns_

-   `?*`: Block support value

### getBlockType

Returns a block type by name.

_Parameters_

-   _state_ `Object`: Data state.
-   _name_ `string`: Block type name.

_Returns_

-   `Object?`: Block Type.

### getBlockTypes

Returns all the available block types.

_Parameters_

-   _state_ `Object`: Data state.

_Returns_

-   `Array`: Block Types.

### getBlockVariations

Returns block variations by block name.

_Parameters_

-   _state_ `Object`: Data state.
-   _blockName_ `string`: Block type name.
-   _scope_ `[WPBlockVariationScope]`: Block variation scope name.

_Returns_

-   `(WPBlockVariation[]|void)`: Block variations.

### getCategories

Returns all the available categories.

_Parameters_

-   _state_ `Object`: Data state.

_Returns_

-   `WPBlockCategory[]`: Categories list.

### getChildBlockNames

Returns an array with the child blocks of a given block.

_Parameters_

-   _state_ `Object`: Data state.
-   _blockName_ `string`: Block type name.

_Returns_

-   `Array`: Array of child block names.

### getCollections

Returns all the available collections.

_Parameters_

-   _state_ `Object`: Data state.

_Returns_

-   `Object`: Collections list.

### getDefaultBlockName

Returns the name of the default block name.

_Parameters_

-   _state_ `Object`: Data state.

_Returns_

-   `string?`: Default block name.

### getDefaultBlockVariation

Returns the default block variation for the given block type.
When there are multiple variations annotated as the default one,
the last added item is picked. This simplifies registering overrides.
When there is no default variation set, it returns the first item.

_Parameters_

-   _state_ `Object`: Data state.
-   _blockName_ `string`: Block type name.
-   _scope_ `[WPBlockVariationScope]`: Block variation scope name.

_Returns_

-   `?WPBlockVariation`: The default block variation.

### getFreeformFallbackBlockName

Returns the name of the block for handling non-block content.

_Parameters_

-   _state_ `Object`: Data state.

_Returns_

-   `string?`: Name of the block for handling non-block content.

### getGroupingBlockName

Returns the name of the block for handling unregistered blocks.

_Parameters_

-   _state_ `Object`: Data state.

_Returns_

-   `string?`: Name of the block for handling unregistered blocks.

### getUnregisteredFallbackBlockName

Returns the name of the block for handling unregistered blocks.

_Parameters_

-   _state_ `Object`: Data state.

_Returns_

-   `string?`: Name of the block for handling unregistered blocks.

### hasBlockSupport

Returns true if the block defines support for a feature, or false otherwise.

_Parameters_

-   _state_ `Object`: Data state.
-   _nameOrType_ `(string|Object)`: Block name or type object.
-   _feature_ `string`: Feature to test.
-   _defaultSupports_ `boolean`: Whether feature is supported by default if not explicitly defined.

_Returns_

-   `boolean`: Whether block supports feature.

### hasChildBlocks

Returns a boolean indicating if a block has child blocks or not.

_Parameters_

-   _state_ `Object`: Data state.
-   _blockName_ `string`: Block type name.

_Returns_

-   `boolean`: True if a block contains child blocks and false otherwise.

### hasChildBlocksWithInserterSupport

Returns a boolean indicating if a block has at least one child block with inserter support.

_Parameters_

-   _state_ `Object`: Data state.
-   _blockName_ `string`: Block type name.

_Returns_

-   `boolean`: True if a block contains at least one child blocks with inserter support and false otherwise.

### isMatchingSearchTerm

Returns true if the block type by the given name or object value matches a
search term, or false otherwise.

_Parameters_

-   _state_ `Object`: Blocks state.
-   _nameOrType_ `(string|Object)`: Block name or type object.
-   _searchTerm_ `string`: Search term by which to filter.

_Returns_

-   `Object[]`: Whether block type matches search term.

<!-- END TOKEN(Autogenerated selectors|../../../packages/blocks/src/store/selectors.js) -->

## Actions

<!-- START TOKEN(Autogenerated actions|../../../packages/blocks/src/store/actions.js) -->

### addBlockCollection

Returns an action object used to add block collections

_Parameters_

-   _namespace_ `string`: The namespace of the blocks to put in the collection
-   _title_ `string`: The title to display in the block inserter
-   _icon_ `Object`: (optional) The icon to display in the block inserter

_Returns_

-   `Object`: Action object.

### addBlockStyles

Returns an action object used in signalling that new block styles have been added.

_Parameters_

-   _blockName_ `string`: Block name.
-   _styles_ `Array|Object`: Block styles.

_Returns_

-   `Object`: Action object.

### addBlockTypes

Returns an action object used in signalling that block types have been added.

_Parameters_

-   _blockTypes_ `Array|Object`: Block types received.

_Returns_

-   `Object`: Action object.

### addBlockVariations

Returns an action object used in signalling that new block variations have been added.

_Parameters_

-   _blockName_ `string`: Block name.
-   _variations_ `WPBlockVariation|WPBlockVariation[]`: Block variations.

_Returns_

-   `Object`: Action object.

### removeBlockCollection

Returns an action object used to remove block collections

_Parameters_

-   _namespace_ `string`: The namespace of the blocks to put in the collection

_Returns_

-   `Object`: Action object.

### removeBlockStyles

Returns an action object used in signalling that block styles have been removed.

_Parameters_

-   _blockName_ `string`: Block name.
-   _styleNames_ `Array|string`: Block style names.

_Returns_

-   `Object`: Action object.

### removeBlockTypes

Returns an action object used to remove a registered block type.

_Parameters_

-   _names_ `string|Array`: Block name.

_Returns_

-   `Object`: Action object.

### removeBlockVariations

Returns an action object used in signalling that block variations have been removed.

_Parameters_

-   _blockName_ `string`: Block name.
-   _variationNames_ `string|string[]`: Block variation names.

_Returns_

-   `Object`: Action object.

### setCategories

Returns an action object used to set block categories.

_Parameters_

-   _categories_ `Object[]`: Block categories.

_Returns_

-   `Object`: Action object.

### setDefaultBlockName

Returns an action object used to set the default block name.

_Parameters_

-   _name_ `string`: Block name.

_Returns_

-   `Object`: Action object.

### setFreeformFallbackBlockName

Returns an action object used to set the name of the block used as a fallback
for non-block content.

_Parameters_

-   _name_ `string`: Block name.

_Returns_

-   `Object`: Action object.

### setGroupingBlockName

Returns an action object used to set the name of the block used
when grouping other blocks
eg: in "Group/Ungroup" interactions

_Parameters_

-   _name_ `string`: Block name.

_Returns_

-   `Object`: Action object.

### setUnregisteredFallbackBlockName

Returns an action object used to set the name of the block used as a fallback
for unregistered blocks.

_Parameters_

-   _name_ `string`: Block name.

_Returns_

-   `Object`: Action object.

### updateCategory

Returns an action object used to update a category.

_Parameters_

-   _slug_ `string`: Block category slug.
-   _category_ `Object`: Object containing the category properties that should be updated.

_Returns_

-   `Object`: Action object.

<!-- END TOKEN(Autogenerated actions|../../../packages/blocks/src/store/actions.js) -->
