# Block library

Block library for the WordPress editor.

## Installation

Install the module

```bash
npm install @wordpress/block-library --save
```

_This package assumes that your code will run in an **ES2015+** environment. If you're using an environment that has limited or no support for such language features and APIs, you should include [the polyfill shipped in `@wordpress/babel-preset-default`](https://github.com/WordPress/gutenberg/tree/HEAD/packages/babel-preset-default#polyfill) in your code._

## Building JavaScript for the browser

If a `view.js` file is present in the block's directory, this file will be built along other assets, making it available to load from the browser.

This enables us to, for instance, load this file when the block is present on the page in two ways:

1.  Using the block's `render_callback`:

```php
function render_block_my_block() {
	$script_path = __DIR__ . '/my-block/view.js';

 	if ( file_exists( $script_path ) ) {
 		wp_enqueue_script(
 			'wp-block-my-block-view',
 			plugins_url( 'view.js', $script_path ),
 			array(),
 			false,
 			true
 		);
 	}
}

function register_block_my_block() {
	register_block_type(
		__DIR__ . '/my-block',
		array(
			'render_callback' => 'render_block_my_block',
		)
	);
}


add_action( 'init', 'register_block_my_block' );
```

2.  Using the `render_block` filter:

```php
function render_block_my_block() {
	$script_path = __DIR__ . '/my-block/view.js';

 	if ( file_exists( $script_path ) ) {
 		wp_enqueue_script(
 			'wp-block-my-block-view',
 			plugins_url( 'view.js', $script_path ),
 			array(),
 			false,
 			true
 		);
 	}
}

apply_filter( 'render_block', 'render_block_my_block' );
```

## API

<!-- START TOKEN(Autogenerated API docs) -->

### registerCoreBlocks

Function to register core blocks provided by the block editor.

_Usage_

```js
import { registerCoreBlocks } from '@wordpress/block-library';

registerCoreBlocks();
```

_Parameters_

-   _blocks_ `Array`: An optional array of the core blocks being registered.

<!-- END TOKEN(Autogenerated API docs) -->

<br/><br/><p align="center"><img src="https://s.w.org/style/images/codeispoetry.png?1" alt="Code is Poetry." /></p>
